@@ -5,12 +5,9 @@ import logging
 import logging.handlers
 
 
+logging.basicConfig(format=f'%(module)s.{__name__}: %(message)s')
 log = logging.getLogger(__name__)
 log.setLevel(logging.DEBUG)
-handler = logging.handlers.SysLogHandler(address='/dev/log')
-formatter = logging.Formatter(f'%(module)s.{__name__}: %(message)s')
-handler.setFormatter(formatter)
-log.addHandler(handler)
 
 
 URL_1 = "http://www.cdep.ru/index.php?id=32"
